Coverage for C:\src\imod-python\imod\flow\sto.py: 100%

1 from imod.flow.pkgbase import Package

2

3

4 class StorageCoefficient(Package):

5 """

6 Storage coefficient [-]. Be careful, this is not the same as the specific

7 storage.

8

9 From wikipedia (https://en.wikipedia.org/wiki/Specific_storage):

10

11 Storativity or the storage coefficient is the volume of water released

12 from storage per unit decline in hydraulic head in the aquifer, per

13 unit area of the aquifer. Storativity is a dimensionless quantity, and

14 is always greater than 0.

15

16 Under confined conditions:

17

18 S = Ss * b, where S is the storage coefficient,

19 Ss the specific storage, and b the aquifer thickness.

20

21 Under unconfined conditions:

22

23 S = Sy, where Sy is the specific yield

24

25 Parameters

26 ----------

27 storage_coefficient : float or xr.DataArray

28 Storage coefficient, dims = ("layer", "y", "x").

29

30 """

31

32 _pkg_id = "sto"

33 _variable_order = ["storage_coefficient"]

34

35 def __init__(self, storage_coefficient):

36 super().__init__()

37 self.dataset["storage_coefficient"] = storage_coefficient

38

39

40 class SpecificStorage(Package):

41 """

42 Specific storage [L-1]. Be careful, this is not the same as the storage

43 coefficient.

44

45 From wikipedia (https://en.wikipedia.org/wiki/Specific_storage):

46

47 The specific storage is the amount of water that a portion of an aquifer

48 releases from storage, per unit mass or volume of aquifer, per unit change

49 in hydraulic head, while remaining fully saturated.

50

51 Parameters

52 ----------

53 specific_storage : float or xr.DataArray

54 Specific storage, dims ``("layer", "y", "x")``.

55 """

56

57 _pkg_id = "ssc"

58 _variable_order = ["specific_storage"]

59

60 def __init__(self, specific_storage):

61 super().__init__()

62 self.dataset["specific_storage"] = specific_storage